IPC (Inter-Process Communication) for Claude Code wrapper
This module handles communication between Claude Code and Parry using stdin/stdout JSON protocol.
Structs
- IpcChannel
- IPC channel for Claude Code communication
IPC (Inter-Process Communication) for Claude Code wrapper
This module handles communication between Claude Code and Parry using stdin/stdout JSON protocol.